imatinib.pdb was generated by running `obabel -imol2 imatinib.mol2 -opdb > imatinib.pdb`


freesolve_v0.3.tar.bz2 is a modified version of David Mobley's FreeSolve database (http://www.escholarship.org/uc/item/6sd403pz).  I have deleted the gromacs top files and SDF files to save space in our repo.


1am7_protein.pdb, 1am7_corrected.xtc, and 1am7_uncorrected.xtc are Gromacs trajectories of lambda phage lysozyme (PDB: 1AM7).  The uncorrected xtc file has the protein drifting across the periodic box.  The
corrected xtc file has been corrected with trjconv -pbc mol.  This are useful as a sanity check for PBC issues.
